@@ -159,9 +159,9 @@ class DataFile(object):
                         A4 = np.array(instr.get('calib{}/a4offset'.format(str(binning))))
                         bound = np.array(instr.get('calib{}/boundaries'.format(str(binning))))
                         calibrations.append([EfTable,A4,bound])
-                    self.instrumentCalibrations = np.array(calibrations)
+                    self.instrumentCalibrations = np.array(calibrations,dtype=object)
                     self.loadBinning(self.binning)
-                    
+                        
                     self.temperature = np.array(sample.get('temperature'))
                     self.magneticField = np.array(sample.get('magnetic_field'))
                     self.electricField = np.array(sample.get('electric_field'))
@@ -700,8 +700,8 @@ class DataFile(object):
             Data.shape = (Data.shape[0],Data.shape[1],-1)
 
         A4Zero = self.A4Off#file.get('entry/sample/polar_angle_zero')
-        
-        
+
+       
         if A4Zero is None:
             A4Zero=0.0
         else:
@@ -721,7 +721,7 @@ class DataFile(object):
         
         A4File = A4File.reshape((-1,1,1))
 
-        A4Mean = -(A4.reshape((1,detectors,binning*EPrDetector))+np.deg2rad(A4File-A4Zero))
+        A4Mean = (A4.reshape((1,detectors,binning*EPrDetector))+np.deg2rad(A4File-A4Zero))
         
         Intensity=np.zeros((Data.shape[0],Data.shape[1],EPrDetector*binning),dtype=int)
         for i in range(detectors): # for each detector
@@ -731,8 +731,8 @@ class DataFile(object):
 
         
         EfMean = EfNormalization[:,1].reshape(1,A4.shape[0],EPrDetector*binning)
-        #EfNormalization = EfNormalization[:,0].reshape(1,A4.shape[0],EPrDetector*binning)#
-        EfNormalization = EfNormalization[:,0]*(np.sqrt(2*np.pi)*EfNormalization[:,2])
+        EfNormalization = EfNormalization[:,0]#.reshape(1,A4.shape[0],EPrDetector*binning)#
+        #EfNormalization = EfNormalization[:,0]*(np.sqrt(2*np.pi)*EfNormalization[:,2])
         
         EfNormalization.shape = (1,A4.shape[0],EPrDetector*binning)
         A3 = np.deg2rad(np.array(self.A3).copy())+A3Zero #file.get('/entry/sample/rotation_angle/')
@@ -755,7 +755,7 @@ class DataFile(object):
             UB = self.sample.orientationMatrix
             UBINV = np.linalg.inv(UB)
             HKL,QX,QY = TasUBlib.calcTasQH(UBINV,[np.rad2deg(A3),
-                -np.rad2deg(A4Mean)],Ei,EfMean)
+                np.rad2deg(A4Mean)],Ei,EfMean)
             H,K,L = np.swapaxes(np.swapaxes(HKL,1,2),0,3)
             self.sample.B = TasUBlib.calculateBMatrix(self.sample.cell)
 
@@ -1522,12 +1522,15 @@ def getScanParameter(f):
     
     for item in f.get('/entry/data/'):
         if not item in ['counts','summed_counts','en','h','intensity','k','l','monitor',
-        'normalization','qx','qy']:
+        'normalization','qx','qy'] and item[-4:]!='zero':
             scanParameters.append(item)
             fItem = f.get('/entry/data/{}'.format(item))
             scanUnits.append(decodeStr(fItem.attrs['units']))
             scanValues.append(np.array(fItem))
-            scanDataPosition.append(decodeStr(fItem.attrs['target']))
+            try:
+                scanDataPosition.append(decodeStr(fItem.attrs['target']))
+            except:
+                pass
 
 
     return scanParameters,np.array(scanValues),scanUnits,scanDataPosition
